==> geeklog-1.5.1-jp-extended-1.4.zip: geeklog-1.5.1-jp-extended-1.4/plugins/autotags/language/japanese.php <==
<?php

###############################################################################
# japanese.php
# This is the japanese(EUC-JP) language page for the Geeklog Autotags Plug-in!
#
# Copyright (C) 2006 Joe Mucchiello
# Tranlated by Ivy (Geeklog Japanese)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################
# Last Update 2008/01/14 by Ivy (Geeklog Japanese)

$LANG_CHARSET = 'euc-jp';

$LANG_AUTO = array(
    'newpage' => 'ڡ',
    'adminhome' => 'HOME',
    'tag' => '̾ʱѿ',
    'desc' => '',
    'replacement' => 'ִʸ',
    'enabled' => 'ͭ:',
    'function' => 'ؿִ:',
    'short_function' => 'ؿ',
    'autotagseditor' => 'ưǥ',
    'autotagsmanager' => 'ưޥ͡',
    'edit' => 'Խ',
    'save' => '¸',
    'delete' => '',
    'cancel' => '󥻥',
    
    'access_denied' => 'ݤޤ',
    'access_denied_msg' => 'Ūڡδѥڡ˥ƤޤΥϵϿޤΤǤλ',
    'deny_msg' => 'ΥڡؤΥݤޤڡ뤤ϥ͡व줿ΤΤޤ󤷡ޤϥ¤ʤΤ⤷ޤ',

    'php_msg_enabled' => 'åȡphpautotags_ ȤƬդΥ̾̾ȤؿȤΥвäȤؿϥ뤵쥿ִޤ <b>ִʸ</b> եʸ̵뤵ޤ',
    'php_msg_disabled' => 'ִ뤿δؿ򥳡뤹뼫ưԽ뤿ˤϡconfig.php ѿ $_AUTO_CONF[\'allow_php\']  \'1\' ꤷ autotags.PHP ¤򥰥롼פͿɬפޤ',
    
    'disallowed_tag' => '򤷤ϻȤޤ¾Ǥ',
    'duplicate_tag' => '򤷤ϤǤФƤޤ¾Υ֤ԽƤ',
    'no_tag_or_replacement' => '<b></b><b>ִʸ</b>եɤɬϤƤ',

    'instructions' => '<p>ưԽϡԽ򥯥åƤϡ""򥯥åƤԽǤʤͭˤǤʤϡϴؿ١ΥǤꡢʤ autotags.PHP ¤ʤѿ $_AUTO_CONF ˤؿ١μư̵ˤʤäƤޤ</p>',
    'replace_explain' => 'ưεҷ <b>[tag:parameter1 parameter2]</b> Ǥ<br>ִʸեɤˤHTML򵭽ҤǤޤ<br>ִʸեɤʸ <b>#1</b>  <b>#2</b> 򵭽Ҥ뤳Ȥˤꡢ<b>parameter1</b>  <b>parameter2</b> ޤ뤳ȤǤޤ</p>'
                        .'<p>ưϡŪ˥󥯤뤿˻Ѥޤ<br> <b>[tag:foo This is a link]</b> ִʸեɤʸ<br> <b>&lt;a href="http://path.to.somewhere/#1"&gt;#2&lt;/a&gt;</b> <br>˴ϢդƤȤΥʸ<br> <b>&lt;a href="http://path.to.somewhere/foo"&gt;This is a link&lt;/a&gt;</b><br>ִޤ</p>'
                        . '<p>#1  #2 ˲äơ<b>#0</b> ϺǽΥθʸǤ <b>#U</b> ϥȤΥ١URLǤ</p>',

    'php_not_activated' => 'ŪڡPHPϵǽƤޤ󡣾ܤ<a href="' . $_CONF['site_url'] . '/docs/staticpages.html#php">ɥ</a>',

    'edit' => 'Խ',

    'search' => '',
    'submit' => '',
    
    'list_all_title' => 'ưꥹ',
    'window_close' => '',
    'main_menulabel' => 'ưꥹ',

    'descr_story' => 'ΥȤεμư: [story:story_id]',
    'descr_event' => 'ΥȤΥ٥Ȥμư: [event:event_id]',
    'descr_calendar' => 'ΥȤΥμư: [calendar:event_id]',
    'descr_link' => 'ΥȤΥ󥯤μư: [link:link_id]',
    'descr_staticpage' => 'ΥȤŪڡμư: [staticpage:page_id]'
);

?>

==> geeklog-1.7.1-jp-extended-1.1.zip: geeklog-1.7.1-jp-extended-1.1/plugins/autotags/language/japanese.php <==
<?php

###############################################################################
# japanese.php
# This is the japanese(EUC-JP) language page for the Geeklog Autotags Plug-in!
#
# Copyright (C) 2006 Joe Mucchiello
# Tranlated by Ivy (Geeklog Japanese)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################
# Last Update 2008/01/14 by Ivy (Geeklog Japanese)

$LANG_AUTO = array(
    'newpage' => 'ڡ',
    'adminhome' => 'HOME',
    'tag' => '̾ʱѿ',
    'desc' => '',
    'replacement' => 'ִʸ',
    'enabled' => 'ͭ:',
    'function' => 'ؿִ:',
    'short_function' => 'ؿ',
    'autotagseditor' => 'ưǥ',
    'autotagsmanager' => 'ưޥ͡',
    'edit' => 'Խ',
    'save' => '¸',
    'delete' => '',
    'cancel' => '󥻥',
    
    'access_denied' => 'ݤޤ',
    'access_denied_msg' => 'Ūڡδѥڡ˥ƤޤΥϵϿޤΤǤλ',
    'deny_msg' => 'ΥڡؤΥݤޤڡ뤤ϥ͡व줿ΤΤޤ󤷡ޤϥ¤ʤΤ⤷ޤ',

    'php_msg_enabled' => 'åȡphpautotags_ ȤƬդΥ̾̾ȤؿȤΥвäȤؿϥ뤵쥿ִޤ <b>ִʸ</b> եʸ̵뤵ޤ',
    'php_msg_disabled' => 'ִ뤿δؿ򥳡뤹뼫ưԽ뤿ˤϡconfig.php ѿ $_AUTO_CONF[\'allow_php\']  \'1\' ꤷ autotags.PHP ¤򥰥롼פͿɬפޤ',
    
    'disallowed_tag' => '򤷤ϻȤޤ¾Ǥ',
    'duplicate_tag' => '򤷤ϤǤФƤޤ¾Υ֤ԽƤ',
    'no_tag_or_replacement' => '<b></b><b>ִʸ</b>եɤɬϤƤ',

    'instructions' => '<p>ưԽϡԽ򥯥åƤϡ""򥯥åƤԽǤʤͭˤǤʤϡϴؿ١ΥǤꡢʤ autotags.PHP ¤ʤѿ $_AUTO_CONF ˤؿ١μư̵ˤʤäƤޤ</p>',
    'replace_explain' => 'ưεҷ <b>[tag:parameter1 parameter2]</b> Ǥ<br' . XHTML . '>ִʸեɤˤHTML򵭽ҤǤޤ<br' . XHTML . '>ִʸեɤʸ <b>#1</b>  <b>#2</b> 򵭽Ҥ뤳Ȥˤꡢ<b>parameter1</b>  <b>parameter2</b> ޤ뤳ȤǤޤ</p>'
                        .'<p>ưϡŪ˥󥯤뤿˻Ѥޤ<br' . XHTML . '> <b>[tag:foo This is a link]</b> ִʸեɤʸ<br' . XHTML . '> <b>&lt;a href="http://path.to.somewhere/#1"&gt;#2&lt;/a&gt;</b> <br' . XHTML . '>˴ϢդƤȤΥʸ<br' . XHTML . '> <b>&lt;a href="http://path.to.somewhere/foo"&gt;This is a link&lt;/a&gt;</b><br' . XHTML . '>ִޤ</p>'
                        . '<p>#1  #2 ˲äơ<b>#0</b> ϺǽΥθʸǤ <b>#U</b> ϥȤΥ١URLǤ</p>',

    'php_not_activated' => 'ŪڡPHPͭˤʤäƤޤ󡣾ܤ<a href="' . $_CONF['site_url'] . '/docs/japanese/staticpages.html#php">ɥ</a>',

    'edit' => 'Խ',

    'search' => '',
    'submit' => '',
    
    'list_all_title' => 'ưꥹ',
    'window_close' => '',
    'main_menulabel' => 'ưꥹ',

    'descr_story' => 'ΥȤεμư: [story:story_id]',
    'descr_event' => 'ΥȤΥ٥Ȥμư: [event:event_id]',
    'descr_calendar' => 'ΥȤΥμư: [calendar:event_id]',
    'descr_link' => 'ΥȤΥ󥯤μư: [link:link_id]',
    'descr_staticpage' => 'ΥȤŪڡμư: [staticpage:page_id]',
// Added since 1.02jp3
	'admin_label' => 'ư',
);

?>
